# coding: utf-8

"""
    Sedaro Satellite API

     Allows for consumption of Sedaro Satellite services. Read more about Sedaro Satellite at [docs.sedaro.com](https://docs.sedaro.com).  ### Clients  **Python:** [sedaro](https://pypi.org/project/sedaro/) - This package provides additional functionality on top of the auto-generated OpenAPI client. See the package docs for more information.  ### Community, Support, Discussion  If you have any issues or suggestions, please reach out:  1. Join the Sedaro Community [Slack](https://join.slack.com/t/sedaro-community/shared_invite/zt-1jps4i711-mXy88AZQ9AV7YcEXr8x7Ow) 2. Email us at support@sedarotech.com  ### Known Issues  - Currently the documentation for 200 responses to Block create, read, update, and delete (CRUD) operations is incorrect. This is due to an issue with our documentation generator.  Under each Block Group, the documentation will show `name`, `collection`, and `data` keys.  In reality, this level does not exist and should be skipped.  See the schema under the `data` key of a Template's Block Group for the correct schema of such Block Group. - Error responses are most specific than what is shown throughout the documentation.  A 4xx or 5xx error will be returned in all error cases.  Only a `200` status indicates success.  See a given error response for additional details.   # noqa: E501

    The version of the OpenAPI document: 3.3.4
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from sedaro_base_client import schemas  # noqa: F401


class TempControllerStateUpdate(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "constantTemperature",
            "tempController",
            "name",
        }
        
        class properties:
            
            
            class name(
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    max_length = 100
            constantTemperature = schemas.NumberSchema
            tempController = schemas.StrSchema
            id = schemas.StrSchema
            
            
            class operationalModes(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.AnyTypeSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'operationalModes':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "name": name,
                "constantTemperature": constantTemperature,
                "tempController": tempController,
                "id": id,
                "operationalModes": operationalModes,
            }
    
    constantTemperature: MetaOapg.properties.constantTemperature
    tempController: MetaOapg.properties.tempController
    name: MetaOapg.properties.name
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["constantTemperature"]) -> MetaOapg.properties.constantTemperature: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tempController"]) -> MetaOapg.properties.tempController: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["operationalModes"]) -> MetaOapg.properties.operationalModes: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "constantTemperature", "tempController", "id", "operationalModes", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["constantTemperature"]) -> MetaOapg.properties.constantTemperature: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tempController"]) -> MetaOapg.properties.tempController: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["operationalModes"]) -> typing.Union[MetaOapg.properties.operationalModes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "constantTemperature", "tempController", "id", "operationalModes", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        constantTemperature: typing.Union[MetaOapg.properties.constantTemperature, decimal.Decimal, int, float, ],
        tempController: typing.Union[MetaOapg.properties.tempController, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        operationalModes: typing.Union[MetaOapg.properties.operationalModes, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'TempControllerStateUpdate':
        return super().__new__(
            cls,
            *_args,
            constantTemperature=constantTemperature,
            tempController=tempController,
            name=name,
            id=id,
            operationalModes=operationalModes,
            _configuration=_configuration,
            **kwargs,
        )



from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_states_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_states_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdThermalTempControllersStatesBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass



from sedaro_base_client.paths.models_branches_branch_id_thermal_temp_controllers_coolers_.post import ApiForpost


class ModelsBranchesBranchIdThermalTempControllersCoolers(
    ApiForpost,
):
    pass



# coding: utf-8

"""
    Sedaro Satellite API

     Allows for consumption of Sedaro Satellite services. Read more about Sedaro Satellite at [docs.sedaro.com](https://docs.sedaro.com).  ### Clients  **Python:** [sedaro](https://pypi.org/project/sedaro/) - This package provides additional functionality on top of the auto-generated OpenAPI client. See the package docs for more information.  ### Community, Support, Discussion  If you have any issues or suggestions, please reach out:  1. Join the Sedaro Community [Slack](https://join.slack.com/t/sedaro-community/shared_invite/zt-1jps4i711-mXy88AZQ9AV7YcEXr8x7Ow) 2. Email us at support@sedarotech.com  ### Known Issues  - Currently the documentation for 200 responses to Block create, read, update, and delete (CRUD) operations is incorrect. This is due to an issue with our documentation generator.  Under each Block Group, the documentation will show `name`, `collection`, and `data` keys.  In reality, this level does not exist and should be skipped.  See the schema under the `data` key of a Template's Block Group for the correct schema of such Block Group. - Error responses are most specific than what is shown throughout the documentation.  A 4xx or 5xx error will be returned in all error cases.  Only a `200` status indicates success.  See a given error response for additional details.   # noqa: E501

    The version of the OpenAPI document: 3.3.4
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from sedaro_base_client import schemas  # noqa: F401


class VehicleTemplate(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "latestId",
            "satellite",
            "conOps",
        }
        
        class properties:
            latestId = schemas.StrSchema
            conOps = schemas.StrSchema
            satellite = schemas.StrSchema
            
            
            class Algorithm(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            AlgorithmBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Algorithm':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Battery(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            BatteryBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Battery':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class BatteryCell(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            BatteryCellBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'BatteryCell':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class BodyFrameVector(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            BodyFrameVectorBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'BodyFrameVector':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class BusRegulator(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            BusRegulatorBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'BusRegulator':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Component(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ComponentBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Component':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class ConOps(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ConOpsBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'ConOps':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Condition(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ConditionBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Condition':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class DataBus(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DataBusBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'DataBus':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class DataMode(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DataModeBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'DataMode':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class DataInterface(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DataInterfaceBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'DataInterface':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class DataStorage(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DataStorageBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'DataStorage':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class DataType(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            DataTypeBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'DataType':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class SameTargetConditionGrouping(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SameTargetConditionGroupingBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'SameTargetConditionGrouping':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class FieldOfView(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            FieldOfViewBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'FieldOfView':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class FOVConstraint(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            FOVConstraintBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'FOVConstraint':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class FuelReservoir(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            FuelReservoirBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'FuelReservoir':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Load(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            LoadBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Load':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class LoadState(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            LoadStateBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'LoadState':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class OperationalMode(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            OperationalModeBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'OperationalMode':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Orbit(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            OrbitBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Orbit':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class PointingMode(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            PointingModeBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'PointingMode':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class ReferenceVector(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ReferenceVectorBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'ReferenceVector':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Satellite(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SatelliteBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Satellite':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class SolarArray(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SolarArrayBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'SolarArray':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class SolarCell(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SolarCellBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'SolarCell':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Subsystem(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SubsystemBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Subsystem':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Surface(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SurfaceBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Surface':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class SurfaceMaterial(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            SurfaceMaterialBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'SurfaceMaterial':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class TargetGroup(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            TargetGroupBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'TargetGroup':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class Target(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            TargetBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'Target':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class TempControllerState(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            TempControllerStateBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'TempControllerState':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class ThermalInterface(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ThermalInterfaceBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'ThermalInterface':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class ThermalInterfaceMaterial(
                schemas.ComposedSchema,
            ):
            
            
                class MetaOapg:
                    
                    @classmethod
                    @functools.lru_cache()
                    def all_of(cls):
                        # we need this here to make our import statements work
                        # we must store _composed_schemas in here so the code is only run
                        # when we invoke this method. If we kept this at the class
                        # level we would get an error because the class level
                        # code would be run when this module is imported, and these composed
                        # classes don't exist yet because their module has not finished
                        # loading
                        return [
                            ThermalInterfaceMaterialBG,
                        ]
            
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'ThermalInterfaceMaterial':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            position = schemas.AnyTypeSchema
            velocity = schemas.AnyTypeSchema
            torque = schemas.AnyTypeSchema
            positionSolution = schemas.AnyTypeSchema
            positionCovariance = schemas.AnyTypeSchema
            velocitySolution = schemas.AnyTypeSchema
            velocityCovariance = schemas.AnyTypeSchema
            __annotations__ = {
                "latestId": latestId,
                "conOps": conOps,
                "satellite": satellite,
                "Algorithm": Algorithm,
                "Battery": Battery,
                "BatteryCell": BatteryCell,
                "BodyFrameVector": BodyFrameVector,
                "BusRegulator": BusRegulator,
                "Component": Component,
                "ConOps": ConOps,
                "Condition": Condition,
                "DataBus": DataBus,
                "DataMode": DataMode,
                "DataInterface": DataInterface,
                "DataStorage": DataStorage,
                "DataType": DataType,
                "SameTargetConditionGrouping": SameTargetConditionGrouping,
                "FieldOfView": FieldOfView,
                "FOVConstraint": FOVConstraint,
                "FuelReservoir": FuelReservoir,
                "Load": Load,
                "LoadState": LoadState,
                "OperationalMode": OperationalMode,
                "Orbit": Orbit,
                "PointingMode": PointingMode,
                "ReferenceVector": ReferenceVector,
                "Satellite": Satellite,
                "SolarArray": SolarArray,
                "SolarCell": SolarCell,
                "Subsystem": Subsystem,
                "Surface": Surface,
                "SurfaceMaterial": SurfaceMaterial,
                "TargetGroup": TargetGroup,
                "Target": Target,
                "TempControllerState": TempControllerState,
                "ThermalInterface": ThermalInterface,
                "ThermalInterfaceMaterial": ThermalInterfaceMaterial,
                "position": position,
                "velocity": velocity,
                "torque": torque,
                "positionSolution": positionSolution,
                "positionCovariance": positionCovariance,
                "velocitySolution": velocitySolution,
                "velocityCovariance": velocityCovariance,
            }
    
    latestId: MetaOapg.properties.latestId
    satellite: MetaOapg.properties.satellite
    conOps: MetaOapg.properties.conOps
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["latestId"]) -> MetaOapg.properties.latestId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["conOps"]) -> MetaOapg.properties.conOps: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["satellite"]) -> MetaOapg.properties.satellite: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Algorithm"]) -> MetaOapg.properties.Algorithm: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Battery"]) -> MetaOapg.properties.Battery: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["BatteryCell"]) -> MetaOapg.properties.BatteryCell: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["BodyFrameVector"]) -> MetaOapg.properties.BodyFrameVector: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["BusRegulator"]) -> MetaOapg.properties.BusRegulator: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Component"]) -> MetaOapg.properties.Component: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ConOps"]) -> MetaOapg.properties.ConOps: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Condition"]) -> MetaOapg.properties.Condition: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["DataBus"]) -> MetaOapg.properties.DataBus: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["DataMode"]) -> MetaOapg.properties.DataMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["DataInterface"]) -> MetaOapg.properties.DataInterface: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["DataStorage"]) -> MetaOapg.properties.DataStorage: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["DataType"]) -> MetaOapg.properties.DataType: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["SameTargetConditionGrouping"]) -> MetaOapg.properties.SameTargetConditionGrouping: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["FieldOfView"]) -> MetaOapg.properties.FieldOfView: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["FOVConstraint"]) -> MetaOapg.properties.FOVConstraint: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["FuelReservoir"]) -> MetaOapg.properties.FuelReservoir: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Load"]) -> MetaOapg.properties.Load: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["LoadState"]) -> MetaOapg.properties.LoadState: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["OperationalMode"]) -> MetaOapg.properties.OperationalMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Orbit"]) -> MetaOapg.properties.Orbit: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["PointingMode"]) -> MetaOapg.properties.PointingMode: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ReferenceVector"]) -> MetaOapg.properties.ReferenceVector: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Satellite"]) -> MetaOapg.properties.Satellite: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["SolarArray"]) -> MetaOapg.properties.SolarArray: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["SolarCell"]) -> MetaOapg.properties.SolarCell: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Subsystem"]) -> MetaOapg.properties.Subsystem: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Surface"]) -> MetaOapg.properties.Surface: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["SurfaceMaterial"]) -> MetaOapg.properties.SurfaceMaterial: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["TargetGroup"]) -> MetaOapg.properties.TargetGroup: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["Target"]) -> MetaOapg.properties.Target: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["TempControllerState"]) -> MetaOapg.properties.TempControllerState: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ThermalInterface"]) -> MetaOapg.properties.ThermalInterface: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ThermalInterfaceMaterial"]) -> MetaOapg.properties.ThermalInterfaceMaterial: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["position"]) -> MetaOapg.properties.position: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["velocity"]) -> MetaOapg.properties.velocity: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["torque"]) -> MetaOapg.properties.torque: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["positionSolution"]) -> MetaOapg.properties.positionSolution: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["positionCovariance"]) -> MetaOapg.properties.positionCovariance: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["velocitySolution"]) -> MetaOapg.properties.velocitySolution: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["velocityCovariance"]) -> MetaOapg.properties.velocityCovariance: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["latestId", "conOps", "satellite", "Algorithm", "Battery", "BatteryCell", "BodyFrameVector", "BusRegulator", "Component", "ConOps", "Condition", "DataBus", "DataMode", "DataInterface", "DataStorage", "DataType", "SameTargetConditionGrouping", "FieldOfView", "FOVConstraint", "FuelReservoir", "Load", "LoadState", "OperationalMode", "Orbit", "PointingMode", "ReferenceVector", "Satellite", "SolarArray", "SolarCell", "Subsystem", "Surface", "SurfaceMaterial", "TargetGroup", "Target", "TempControllerState", "ThermalInterface", "ThermalInterfaceMaterial", "position", "velocity", "torque", "positionSolution", "positionCovariance", "velocitySolution", "velocityCovariance", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["latestId"]) -> MetaOapg.properties.latestId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["conOps"]) -> MetaOapg.properties.conOps: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["satellite"]) -> MetaOapg.properties.satellite: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Algorithm"]) -> typing.Union[MetaOapg.properties.Algorithm, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Battery"]) -> typing.Union[MetaOapg.properties.Battery, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["BatteryCell"]) -> typing.Union[MetaOapg.properties.BatteryCell, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["BodyFrameVector"]) -> typing.Union[MetaOapg.properties.BodyFrameVector, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["BusRegulator"]) -> typing.Union[MetaOapg.properties.BusRegulator, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Component"]) -> typing.Union[MetaOapg.properties.Component, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ConOps"]) -> typing.Union[MetaOapg.properties.ConOps, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Condition"]) -> typing.Union[MetaOapg.properties.Condition, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["DataBus"]) -> typing.Union[MetaOapg.properties.DataBus, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["DataMode"]) -> typing.Union[MetaOapg.properties.DataMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["DataInterface"]) -> typing.Union[MetaOapg.properties.DataInterface, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["DataStorage"]) -> typing.Union[MetaOapg.properties.DataStorage, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["DataType"]) -> typing.Union[MetaOapg.properties.DataType, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["SameTargetConditionGrouping"]) -> typing.Union[MetaOapg.properties.SameTargetConditionGrouping, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["FieldOfView"]) -> typing.Union[MetaOapg.properties.FieldOfView, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["FOVConstraint"]) -> typing.Union[MetaOapg.properties.FOVConstraint, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["FuelReservoir"]) -> typing.Union[MetaOapg.properties.FuelReservoir, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Load"]) -> typing.Union[MetaOapg.properties.Load, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["LoadState"]) -> typing.Union[MetaOapg.properties.LoadState, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["OperationalMode"]) -> typing.Union[MetaOapg.properties.OperationalMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Orbit"]) -> typing.Union[MetaOapg.properties.Orbit, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["PointingMode"]) -> typing.Union[MetaOapg.properties.PointingMode, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ReferenceVector"]) -> typing.Union[MetaOapg.properties.ReferenceVector, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Satellite"]) -> typing.Union[MetaOapg.properties.Satellite, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["SolarArray"]) -> typing.Union[MetaOapg.properties.SolarArray, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["SolarCell"]) -> typing.Union[MetaOapg.properties.SolarCell, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Subsystem"]) -> typing.Union[MetaOapg.properties.Subsystem, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Surface"]) -> typing.Union[MetaOapg.properties.Surface, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["SurfaceMaterial"]) -> typing.Union[MetaOapg.properties.SurfaceMaterial, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["TargetGroup"]) -> typing.Union[MetaOapg.properties.TargetGroup, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["Target"]) -> typing.Union[MetaOapg.properties.Target, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["TempControllerState"]) -> typing.Union[MetaOapg.properties.TempControllerState, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ThermalInterface"]) -> typing.Union[MetaOapg.properties.ThermalInterface, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ThermalInterfaceMaterial"]) -> typing.Union[MetaOapg.properties.ThermalInterfaceMaterial, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["position"]) -> typing.Union[MetaOapg.properties.position, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["velocity"]) -> typing.Union[MetaOapg.properties.velocity, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["torque"]) -> typing.Union[MetaOapg.properties.torque, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["positionSolution"]) -> typing.Union[MetaOapg.properties.positionSolution, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["positionCovariance"]) -> typing.Union[MetaOapg.properties.positionCovariance, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["velocitySolution"]) -> typing.Union[MetaOapg.properties.velocitySolution, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["velocityCovariance"]) -> typing.Union[MetaOapg.properties.velocityCovariance, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["latestId", "conOps", "satellite", "Algorithm", "Battery", "BatteryCell", "BodyFrameVector", "BusRegulator", "Component", "ConOps", "Condition", "DataBus", "DataMode", "DataInterface", "DataStorage", "DataType", "SameTargetConditionGrouping", "FieldOfView", "FOVConstraint", "FuelReservoir", "Load", "LoadState", "OperationalMode", "Orbit", "PointingMode", "ReferenceVector", "Satellite", "SolarArray", "SolarCell", "Subsystem", "Surface", "SurfaceMaterial", "TargetGroup", "Target", "TempControllerState", "ThermalInterface", "ThermalInterfaceMaterial", "position", "velocity", "torque", "positionSolution", "positionCovariance", "velocitySolution", "velocityCovariance", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        latestId: typing.Union[MetaOapg.properties.latestId, str, ],
        satellite: typing.Union[MetaOapg.properties.satellite, str, ],
        conOps: typing.Union[MetaOapg.properties.conOps, str, ],
        Algorithm: typing.Union[MetaOapg.properties.Algorithm, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Battery: typing.Union[MetaOapg.properties.Battery, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        BatteryCell: typing.Union[MetaOapg.properties.BatteryCell, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        BodyFrameVector: typing.Union[MetaOapg.properties.BodyFrameVector, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        BusRegulator: typing.Union[MetaOapg.properties.BusRegulator, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Component: typing.Union[MetaOapg.properties.Component, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        ConOps: typing.Union[MetaOapg.properties.ConOps, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Condition: typing.Union[MetaOapg.properties.Condition, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        DataBus: typing.Union[MetaOapg.properties.DataBus, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        DataMode: typing.Union[MetaOapg.properties.DataMode, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        DataInterface: typing.Union[MetaOapg.properties.DataInterface, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        DataStorage: typing.Union[MetaOapg.properties.DataStorage, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        DataType: typing.Union[MetaOapg.properties.DataType, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        SameTargetConditionGrouping: typing.Union[MetaOapg.properties.SameTargetConditionGrouping, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        FieldOfView: typing.Union[MetaOapg.properties.FieldOfView, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        FOVConstraint: typing.Union[MetaOapg.properties.FOVConstraint, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        FuelReservoir: typing.Union[MetaOapg.properties.FuelReservoir, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Load: typing.Union[MetaOapg.properties.Load, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        LoadState: typing.Union[MetaOapg.properties.LoadState, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        OperationalMode: typing.Union[MetaOapg.properties.OperationalMode, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Orbit: typing.Union[MetaOapg.properties.Orbit, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        PointingMode: typing.Union[MetaOapg.properties.PointingMode, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        ReferenceVector: typing.Union[MetaOapg.properties.ReferenceVector, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Satellite: typing.Union[MetaOapg.properties.Satellite, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        SolarArray: typing.Union[MetaOapg.properties.SolarArray, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        SolarCell: typing.Union[MetaOapg.properties.SolarCell, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Subsystem: typing.Union[MetaOapg.properties.Subsystem, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Surface: typing.Union[MetaOapg.properties.Surface, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        SurfaceMaterial: typing.Union[MetaOapg.properties.SurfaceMaterial, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        TargetGroup: typing.Union[MetaOapg.properties.TargetGroup, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        Target: typing.Union[MetaOapg.properties.Target, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        TempControllerState: typing.Union[MetaOapg.properties.TempControllerState, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        ThermalInterface: typing.Union[MetaOapg.properties.ThermalInterface, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        ThermalInterfaceMaterial: typing.Union[MetaOapg.properties.ThermalInterfaceMaterial, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        position: typing.Union[MetaOapg.properties.position, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        velocity: typing.Union[MetaOapg.properties.velocity, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        torque: typing.Union[MetaOapg.properties.torque, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        positionSolution: typing.Union[MetaOapg.properties.positionSolution, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        positionCovariance: typing.Union[MetaOapg.properties.positionCovariance, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        velocitySolution: typing.Union[MetaOapg.properties.velocitySolution, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        velocityCovariance: typing.Union[MetaOapg.properties.velocityCovariance, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'VehicleTemplate':
        return super().__new__(
            cls,
            *_args,
            latestId=latestId,
            satellite=satellite,
            conOps=conOps,
            Algorithm=Algorithm,
            Battery=Battery,
            BatteryCell=BatteryCell,
            BodyFrameVector=BodyFrameVector,
            BusRegulator=BusRegulator,
            Component=Component,
            ConOps=ConOps,
            Condition=Condition,
            DataBus=DataBus,
            DataMode=DataMode,
            DataInterface=DataInterface,
            DataStorage=DataStorage,
            DataType=DataType,
            SameTargetConditionGrouping=SameTargetConditionGrouping,
            FieldOfView=FieldOfView,
            FOVConstraint=FOVConstraint,
            FuelReservoir=FuelReservoir,
            Load=Load,
            LoadState=LoadState,
            OperationalMode=OperationalMode,
            Orbit=Orbit,
            PointingMode=PointingMode,
            ReferenceVector=ReferenceVector,
            Satellite=Satellite,
            SolarArray=SolarArray,
            SolarCell=SolarCell,
            Subsystem=Subsystem,
            Surface=Surface,
            SurfaceMaterial=SurfaceMaterial,
            TargetGroup=TargetGroup,
            Target=Target,
            TempControllerState=TempControllerState,
            ThermalInterface=ThermalInterface,
            ThermalInterfaceMaterial=ThermalInterfaceMaterial,
            position=position,
            velocity=velocity,
            torque=torque,
            positionSolution=positionSolution,
            positionCovariance=positionCovariance,
            velocitySolution=velocitySolution,
            velocityCovariance=velocityCovariance,
            _configuration=_configuration,
            **kwargs,
        )

from sedaro_base_client.model.algorithm_bg import AlgorithmBG
from sedaro_base_client.model.battery_bg import BatteryBG
from sedaro_base_client.model.battery_cell_bg import BatteryCellBG
from sedaro_base_client.model.body_frame_vector_bg import BodyFrameVectorBG
from sedaro_base_client.model.bus_regulator_bg import BusRegulatorBG
from sedaro_base_client.model.component_bg import ComponentBG
from sedaro_base_client.model.con_ops_bg import ConOpsBG
from sedaro_base_client.model.condition_bg import ConditionBG
from sedaro_base_client.model.data_bus_bg import DataBusBG
from sedaro_base_client.model.data_interface_bg import DataInterfaceBG
from sedaro_base_client.model.data_mode_bg import DataModeBG
from sedaro_base_client.model.data_storage_bg import DataStorageBG
from sedaro_base_client.model.data_type_bg import DataTypeBG
from sedaro_base_client.model.field_of_view_bg import FieldOfViewBG
from sedaro_base_client.model.fov_constraint_bg import FOVConstraintBG
from sedaro_base_client.model.fuel_reservoir_bg import FuelReservoirBG
from sedaro_base_client.model.load_bg import LoadBG
from sedaro_base_client.model.load_state_bg import LoadStateBG
from sedaro_base_client.model.operational_mode_bg import OperationalModeBG
from sedaro_base_client.model.orbit_bg import OrbitBG
from sedaro_base_client.model.pointing_mode_bg import PointingModeBG
from sedaro_base_client.model.reference_vector_bg import ReferenceVectorBG
from sedaro_base_client.model.same_target_condition_grouping_bg import SameTargetConditionGroupingBG
from sedaro_base_client.model.satellite_bg import SatelliteBG
from sedaro_base_client.model.solar_array_bg import SolarArrayBG
from sedaro_base_client.model.solar_cell_bg import SolarCellBG
from sedaro_base_client.model.subsystem_bg import SubsystemBG
from sedaro_base_client.model.surface_bg import SurfaceBG
from sedaro_base_client.model.surface_material_bg import SurfaceMaterialBG
from sedaro_base_client.model.target_bg import TargetBG
from sedaro_base_client.model.target_group_bg import TargetGroupBG
from sedaro_base_client.model.temp_controller_state_bg import TempControllerStateBG
from sedaro_base_client.model.thermal_interface_bg import ThermalInterfaceBG
from sedaro_base_client.model.thermal_interface_material_bg import ThermalInterfaceMaterialBG



# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from sedaro_base_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from sedaro_base_client.model.active_pointing_mode import ActivePointingMode
from sedaro_base_client.model.agent import Agent
from sedaro_base_client.model.agent_bg import AgentBG
from sedaro_base_client.model.agent_create import AgentCreate
from sedaro_base_client.model.agent_update import AgentUpdate
from sedaro_base_client.model.algorithm_bg import AlgorithmBG
from sedaro_base_client.model.angular_velocity_sensor import AngularVelocitySensor
from sedaro_base_client.model.angular_velocity_sensor_create import AngularVelocitySensorCreate
from sedaro_base_client.model.angular_velocity_sensor_update import AngularVelocitySensorUpdate
from sedaro_base_client.model.antenna import Antenna
from sedaro_base_client.model.anti_sun_tracking_surface import AntiSunTrackingSurface
from sedaro_base_client.model.att_det_types import AttDetTypes
from sedaro_base_client.model.averaging_algorithm import AveragingAlgorithm
from sedaro_base_client.model.averaging_algorithm_create import AveragingAlgorithmCreate
from sedaro_base_client.model.averaging_algorithm_update import AveragingAlgorithmUpdate
from sedaro_base_client.model.battery import Battery
from sedaro_base_client.model.battery_bg import BatteryBG
from sedaro_base_client.model.battery_cell import BatteryCell
from sedaro_base_client.model.battery_cell_bg import BatteryCellBG
from sedaro_base_client.model.battery_cell_create import BatteryCellCreate
from sedaro_base_client.model.battery_cell_update import BatteryCellUpdate
from sedaro_base_client.model.battery_pack import BatteryPack
from sedaro_base_client.model.battery_pack_create import BatteryPackCreate
from sedaro_base_client.model.battery_pack_update import BatteryPackUpdate
from sedaro_base_client.model.battery_update import BatteryUpdate
from sedaro_base_client.model.body_frame_vector import BodyFrameVector
from sedaro_base_client.model.body_frame_vector_bg import BodyFrameVectorBG
from sedaro_base_client.model.body_frame_vector_create import BodyFrameVectorCreate
from sedaro_base_client.model.body_frame_vector_types import BodyFrameVectorTypes
from sedaro_base_client.model.body_frame_vector_update import BodyFrameVectorUpdate
from sedaro_base_client.model.branch_create import BranchCreate
from sedaro_base_client.model.branch_delete_res import BranchDeleteRes
from sedaro_base_client.model.branch_merge import BranchMerge
from sedaro_base_client.model.branch_merge_conflicts_res import BranchMergeConflictsRes
from sedaro_base_client.model.branch_scenario_res import BranchScenarioRes
from sedaro_base_client.model.branch_update import BranchUpdate
from sedaro_base_client.model.branch_vehicle_res import BranchVehicleRes
from sedaro_base_client.model.branch_verify_password import BranchVerifyPassword
from sedaro_base_client.model.bus_regulator import BusRegulator
from sedaro_base_client.model.bus_regulator_bg import BusRegulatorBG
from sedaro_base_client.model.bus_regulator_create import BusRegulatorCreate
from sedaro_base_client.model.bus_regulator_update import BusRegulatorUpdate
from sedaro_base_client.model.categories import Categories
from sedaro_base_client.model.celestial_pointing_directions import CelestialPointingDirections
from sedaro_base_client.model.celestial_target import CelestialTarget
from sedaro_base_client.model.celestial_target_create import CelestialTargetCreate
from sedaro_base_client.model.celestial_target_update import CelestialTargetUpdate
from sedaro_base_client.model.celestial_vector import CelestialVector
from sedaro_base_client.model.celestial_vector_create import CelestialVectorCreate
from sedaro_base_client.model.celestial_vector_update import CelestialVectorUpdate
from sedaro_base_client.model.circular_field_of_view import CircularFieldOfView
from sedaro_base_client.model.circular_field_of_view_create import CircularFieldOfViewCreate
from sedaro_base_client.model.circular_field_of_view_update import CircularFieldOfViewUpdate
from sedaro_base_client.model.clock_config import ClockConfig
from sedaro_base_client.model.clock_config_bg import ClockConfigBG
from sedaro_base_client.model.clock_config_create import ClockConfigCreate
from sedaro_base_client.model.clock_config_update import ClockConfigUpdate
from sedaro_base_client.model.collection import Collection
from sedaro_base_client.model.component import Component
from sedaro_base_client.model.component_bg import ComponentBG
from sedaro_base_client.model.component_create import ComponentCreate
from sedaro_base_client.model.component_update import ComponentUpdate
from sedaro_base_client.model.con_ops import ConOps
from sedaro_base_client.model.con_ops_bg import ConOpsBG
from sedaro_base_client.model.condition import Condition
from sedaro_base_client.model.condition_bg import ConditionBG
from sedaro_base_client.model.condition_create import ConditionCreate
from sedaro_base_client.model.condition_relationship import ConditionRelationship
from sedaro_base_client.model.condition_update import ConditionUpdate
from sedaro_base_client.model.configuration_types import ConfigurationTypes
from sedaro_base_client.model.conflicts_obj import ConflictsObj
from sedaro_base_client.model.constant_load_create import ConstantLoadCreate
from sedaro_base_client.model.constant_load_definition_types import ConstantLoadDefinitionTypes
from sedaro_base_client.model.constant_load_update import ConstantLoadUpdate
from sedaro_base_client.model.constant_power import ConstantPower
from sedaro_base_client.model.constant_resistance import ConstantResistance
from sedaro_base_client.model.cooler import Cooler
from sedaro_base_client.model.cooler_create import CoolerCreate
from sedaro_base_client.model.cooler_update import CoolerUpdate
from sedaro_base_client.model.data_bus import DataBus
from sedaro_base_client.model.data_bus_bg import DataBusBG
from sedaro_base_client.model.data_interface import DataInterface
from sedaro_base_client.model.data_interface_bg import DataInterfaceBG
from sedaro_base_client.model.data_mode import DataMode
from sedaro_base_client.model.data_mode_bg import DataModeBG
from sedaro_base_client.model.data_service_response import DataServiceResponse
from sedaro_base_client.model.data_set import DataSet
from sedaro_base_client.model.data_storage import DataStorage
from sedaro_base_client.model.data_storage_bg import DataStorageBG
from sedaro_base_client.model.data_type import DataType
from sedaro_base_client.model.data_type_bg import DataTypeBG
from sedaro_base_client.model.deleted_entity import DeletedEntity
from sedaro_base_client.model.directed_energy_device_modes import DirectedEnergyDeviceModes
from sedaro_base_client.model.direction_sensor import DirectionSensor
from sedaro_base_client.model.direction_sensor_create import DirectionSensorCreate
from sedaro_base_client.model.direction_sensor_update import DirectionSensorUpdate
from sedaro_base_client.model.ekf_algorithm import EKFAlgorithm
from sedaro_base_client.model.ekf_algorithm_create import EKFAlgorithmCreate
from sedaro_base_client.model.ekf_algorithm_update import EKFAlgorithmUpdate
from sedaro_base_client.model.eps_output_types import EpsOutputTypes
from sedaro_base_client.model.fov_constraint import FOVConstraint
from sedaro_base_client.model.fov_constraint_bg import FOVConstraintBG
from sedaro_base_client.model.fov_constraint_create import FOVConstraintCreate
from sedaro_base_client.model.fov_constraint_update import FOVConstraintUpdate
from sedaro_base_client.model.field_of_view_bg import FieldOfViewBG
from sedaro_base_client.model.fixed_surface import FixedSurface
from sedaro_base_client.model.fuel_reservoir import FuelReservoir
from sedaro_base_client.model.fuel_reservoir_bg import FuelReservoirBG
from sedaro_base_client.model.fully_reg_det_topology import FullyRegDetTopology
from sedaro_base_client.model.gps_algorithm import GPSAlgorithm
from sedaro_base_client.model.gps_algorithm_create import GPSAlgorithmCreate
from sedaro_base_client.model.gps_algorithm_update import GPSAlgorithmUpdate
from sedaro_base_client.model.ground_target import GroundTarget
from sedaro_base_client.model.ground_target_create import GroundTargetCreate
from sedaro_base_client.model.ground_target_update import GroundTargetUpdate
from sedaro_base_client.model.group_and_id import GroupAndId
from sedaro_base_client.model.group_condition import GroupCondition
from sedaro_base_client.model.group_condition_create import GroupConditionCreate
from sedaro_base_client.model.group_condition_update import GroupConditionUpdate
from sedaro_base_client.model.group_rollers import GroupRollers
from sedaro_base_client.model.http_validation_error import HTTPValidationError
from sedaro_base_client.model.heater import Heater
from sedaro_base_client.model.heater_create import HeaterCreate
from sedaro_base_client.model.heater_update import HeaterUpdate
from sedaro_base_client.model.iro_equatorial_circ import IROEquatorialCirc
from sedaro_base_client.model.iro_geostat import IROGeostat
from sedaro_base_client.model.iro_geostat_transfer import IROGeostatTransfer
from sedaro_base_client.model.iro_iss import IROIss
from sedaro_base_client.model.iro_polar_circ import IROPolarCirc
from sedaro_base_client.model.iro_sun_sync_circ import IROSunSyncCirc
from sedaro_base_client.model.isdp_eci import ISDPEci
from sedaro_base_client.model.isdp_orbital_elements import ISDPOrbitalElements
from sedaro_base_client.model.isdp_tle import ISDPTle
from sedaro_base_client.model.initial_state_def_type import InitialStateDefType
from sedaro_base_client.model.input_types import InputTypes
from sedaro_base_client.model.laser_comm_module import LaserCommModule
from sedaro_base_client.model.load_bg import LoadBG
from sedaro_base_client.model.load_state import LoadState
from sedaro_base_client.model.load_state_bg import LoadStateBG
from sedaro_base_client.model.load_state_create import LoadStateCreate
from sedaro_base_client.model.load_state_update import LoadStateUpdate
from sedaro_base_client.model.local_pointing_directions import LocalPointingDirections
from sedaro_base_client.model.local_vector import LocalVector
from sedaro_base_client.model.local_vector_create import LocalVectorCreate
from sedaro_base_client.model.local_vector_update import LocalVectorUpdate
from sedaro_base_client.model.lock_pointing_mode import LockPointingMode
from sedaro_base_client.model.lock_pointing_mode_create import LockPointingModeCreate
from sedaro_base_client.model.lock_pointing_mode_update import LockPointingModeUpdate
from sedaro_base_client.model.mekf_algorithm import MEKFAlgorithm
from sedaro_base_client.model.mekf_algorithm_create import MEKFAlgorithmCreate
from sedaro_base_client.model.mekf_algorithm_update import MEKFAlgorithmUpdate
from sedaro_base_client.model.magnetorquer import Magnetorquer
from sedaro_base_client.model.magnetorquer_create import MagnetorquerCreate
from sedaro_base_client.model.magnetorquer_update import MagnetorquerUpdate
from sedaro_base_client.model.max_align_pointing_mode import MaxAlignPointingMode
from sedaro_base_client.model.max_align_pointing_mode_create import MaxAlignPointingModeCreate
from sedaro_base_client.model.max_align_pointing_mode_update import MaxAlignPointingModeUpdate
from sedaro_base_client.model.message_res import MessageRes
from sedaro_base_client.model.motion_types import MotionTypes
from sedaro_base_client.model.operational_mode import OperationalMode
from sedaro_base_client.model.operational_mode_bg import OperationalModeBG
from sedaro_base_client.model.operational_mode_create import OperationalModeCreate
from sedaro_base_client.model.operational_mode_update import OperationalModeUpdate
from sedaro_base_client.model.optical_attitude_sensor import OpticalAttitudeSensor
from sedaro_base_client.model.optical_attitude_sensor_create import OpticalAttitudeSensorCreate
from sedaro_base_client.model.optical_attitude_sensor_update import OpticalAttitudeSensorUpdate
from sedaro_base_client.model.orbit import Orbit
from sedaro_base_client.model.orbit_bg import OrbitBG
from sedaro_base_client.model.orbit_create import OrbitCreate
from sedaro_base_client.model.orbit_update import OrbitUpdate
from sedaro_base_client.model.pid_algorithm import PIDAlgorithm
from sedaro_base_client.model.pid_algorithm_create import PIDAlgorithmCreate
from sedaro_base_client.model.pid_algorithm_update import PIDAlgorithmUpdate
from sedaro_base_client.model.parameter_a_categories import ParameterACategories
from sedaro_base_client.model.parameter_b_categories import ParameterBCategories
from sedaro_base_client.model.parameters import Parameters
from sedaro_base_client.model.passive_pointing_mode import PassivePointingMode
from sedaro_base_client.model.passive_pointing_mode_create import PassivePointingModeCreate
from sedaro_base_client.model.passive_pointing_mode_update import PassivePointingModeUpdate
from sedaro_base_client.model.pointing_mode import PointingMode
from sedaro_base_client.model.pointing_mode_bg import PointingModeBG
from sedaro_base_client.model.pointing_mode_types import PointingModeTypes
from sedaro_base_client.model.polynomial_ephemeris_body import PolynomialEphemerisBody
from sedaro_base_client.model.position_sensor import PositionSensor
from sedaro_base_client.model.position_sensor_create import PositionSensorCreate
from sedaro_base_client.model.position_sensor_update import PositionSensorUpdate
from sedaro_base_client.model.power_load import PowerLoad
from sedaro_base_client.model.quasi_reg_det_topology import QuasiRegDetTopology
from sedaro_base_client.model.reaction_wheel import ReactionWheel
from sedaro_base_client.model.reaction_wheel_create import ReactionWheelCreate
from sedaro_base_client.model.reaction_wheel_update import ReactionWheelUpdate
from sedaro_base_client.model.rectangular_field_of_view import RectangularFieldOfView
from sedaro_base_client.model.rectangular_field_of_view_create import RectangularFieldOfViewCreate
from sedaro_base_client.model.rectangular_field_of_view_update import RectangularFieldOfViewUpdate
from sedaro_base_client.model.reference_vector import ReferenceVector
from sedaro_base_client.model.reference_vector_bg import ReferenceVectorBG
from sedaro_base_client.model.reference_vector_types import ReferenceVectorTypes
from sedaro_base_client.model.resistance_load import ResistanceLoad
from sedaro_base_client.model.same_target_condition_grouping import SameTargetConditionGrouping
from sedaro_base_client.model.same_target_condition_grouping_bg import SameTargetConditionGroupingBG
from sedaro_base_client.model.satellite import Satellite
from sedaro_base_client.model.satellite_bg import SatelliteBG
from sedaro_base_client.model.satellite_update import SatelliteUpdate
from sedaro_base_client.model.scenario_block_create_res import ScenarioBlockCreateRes
from sedaro_base_client.model.scenario_block_delete_res import ScenarioBlockDeleteRes
from sedaro_base_client.model.scenario_block_update_res import ScenarioBlockUpdateRes
from sedaro_base_client.model.scenario_template import ScenarioTemplate
from sedaro_base_client.model.side_categories import SideCategories
from sedaro_base_client.model.simulatable_satellite import SimulatableSatellite
from sedaro_base_client.model.simulation_job import SimulationJob
from sedaro_base_client.model.single_conv_hybrid_topology import SingleConvHybridTopology
from sedaro_base_client.model.single_conv_mppt_topology import SingleConvMpptTopology
from sedaro_base_client.model.sliding_mode_algorithm import SlidingModeAlgorithm
from sedaro_base_client.model.sliding_mode_algorithm_create import SlidingModeAlgorithmCreate
from sedaro_base_client.model.sliding_mode_algorithm_update import SlidingModeAlgorithmUpdate
from sedaro_base_client.model.solar_array import SolarArray
from sedaro_base_client.model.solar_array_bg import SolarArrayBG
from sedaro_base_client.model.solar_array_create import SolarArrayCreate
from sedaro_base_client.model.solar_array_update import SolarArrayUpdate
from sedaro_base_client.model.solar_cell import SolarCell
from sedaro_base_client.model.solar_cell_bg import SolarCellBG
from sedaro_base_client.model.solar_cell_create import SolarCellCreate
from sedaro_base_client.model.solar_cell_update import SolarCellUpdate
from sedaro_base_client.model.solar_panel import SolarPanel
from sedaro_base_client.model.solar_panel_create import SolarPanelCreate
from sedaro_base_client.model.solar_panel_update import SolarPanelUpdate
from sedaro_base_client.model.space_target import SpaceTarget
from sedaro_base_client.model.space_target_create import SpaceTargetCreate
from sedaro_base_client.model.space_target_update import SpaceTargetUpdate
from sedaro_base_client.model.spherical_angles import SphericalAngles
from sedaro_base_client.model.spherical_fuel_tank import SphericalFuelTank
from sedaro_base_client.model.spherocylinder_fuel_tank import SpherocylinderFuelTank
from sedaro_base_client.model.static_thrust_control_algorithm import StaticThrustControlAlgorithm
from sedaro_base_client.model.statuses import Statuses
from sedaro_base_client.model.subsystem import Subsystem
from sedaro_base_client.model.subsystem_bg import SubsystemBG
from sedaro_base_client.model.subsystem_create import SubsystemCreate
from sedaro_base_client.model.subsystem_update import SubsystemUpdate
from sedaro_base_client.model.sun_tracking_surface import SunTrackingSurface
from sedaro_base_client.model.surface_bg import SurfaceBG
from sedaro_base_client.model.surface_create import SurfaceCreate
from sedaro_base_client.model.surface_material import SurfaceMaterial
from sedaro_base_client.model.surface_material_bg import SurfaceMaterialBG
from sedaro_base_client.model.surface_material_create import SurfaceMaterialCreate
from sedaro_base_client.model.surface_material_update import SurfaceMaterialUpdate
from sedaro_base_client.model.surface_update import SurfaceUpdate
from sedaro_base_client.model.target_bg import TargetBG
from sedaro_base_client.model.target_group import TargetGroup
from sedaro_base_client.model.target_group_bg import TargetGroupBG
from sedaro_base_client.model.target_group_create import TargetGroupCreate
from sedaro_base_client.model.target_group_update import TargetGroupUpdate
from sedaro_base_client.model.target_group_vector import TargetGroupVector
from sedaro_base_client.model.target_group_vector_create import TargetGroupVectorCreate
from sedaro_base_client.model.target_group_vector_update import TargetGroupVectorUpdate
from sedaro_base_client.model.target_vector import TargetVector
from sedaro_base_client.model.target_vector_create import TargetVectorCreate
from sedaro_base_client.model.target_vector_update import TargetVectorUpdate
from sedaro_base_client.model.temp_controller_state import TempControllerState
from sedaro_base_client.model.temp_controller_state_bg import TempControllerStateBG
from sedaro_base_client.model.temp_controller_state_create import TempControllerStateCreate
from sedaro_base_client.model.temp_controller_state_update import TempControllerStateUpdate
from sedaro_base_client.model.thermal_interface import ThermalInterface
from sedaro_base_client.model.thermal_interface_bg import ThermalInterfaceBG
from sedaro_base_client.model.thermal_interface_create import ThermalInterfaceCreate
from sedaro_base_client.model.thermal_interface_material import ThermalInterfaceMaterial
from sedaro_base_client.model.thermal_interface_material_bg import ThermalInterfaceMaterialBG
from sedaro_base_client.model.thermal_interface_material_create import ThermalInterfaceMaterialCreate
from sedaro_base_client.model.thermal_interface_material_update import ThermalInterfaceMaterialUpdate
from sedaro_base_client.model.thermal_interface_update import ThermalInterfaceUpdate
from sedaro_base_client.model.thruster import Thruster
from sedaro_base_client.model.topology import Topology
from sedaro_base_client.model.topology_param_frd import TopologyParamFRD
from sedaro_base_client.model.topology_param_qrd import TopologyParamQRD
from sedaro_base_client.model.topology_param_sch import TopologyParamSCH
from sedaro_base_client.model.topology_param_scm import TopologyParamSCM
from sedaro_base_client.model.topology_param_tcm import TopologyParamTCM
from sedaro_base_client.model.topology_types import TopologyTypes
from sedaro_base_client.model.topology_update import TopologyUpdate
from sedaro_base_client.model.triad_algorithm import TriadAlgorithm
from sedaro_base_client.model.triad_algorithm_create import TriadAlgorithmCreate
from sedaro_base_client.model.triad_algorithm_update import TriadAlgorithmUpdate
from sedaro_base_client.model.two_conv_mppt_topology import TwoConvMpptTopology
from sedaro_base_client.model.types import Types
from sedaro_base_client.model.validation_error import ValidationError
from sedaro_base_client.model.vector import Vector
from sedaro_base_client.model.vector_sensor import VectorSensor
from sedaro_base_client.model.vector_sensor_create import VectorSensorCreate
from sedaro_base_client.model.vector_sensor_update import VectorSensorUpdate
from sedaro_base_client.model.vehicle_block_create_res import VehicleBlockCreateRes
from sedaro_base_client.model.vehicle_block_delete_res import VehicleBlockDeleteRes
from sedaro_base_client.model.vehicle_block_update_res import VehicleBlockUpdateRes
from sedaro_base_client.model.vehicle_template import VehicleTemplate



from sedaro_base_client.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_block_id.delete import ApiFordelete
from sedaro_base_client.paths.models_branches_branch_id_gnc_reference_vectors_target_group_vectors_block_id.patch import ApiForpatch


class ModelsBranchesBranchIdGncReferenceVectorsTargetGroupVectorsBlockId(
    ApiFordelete,
    ApiForpatch,
):
    pass
